summaryrefslogtreecommitdiffstats
path: root/src/include
diff options
context:
space:
mode:
authorBrian Horton <brianh@linux.ibm.com>2015-01-27 16:24:36 -0600
committerA. Patrick Williams III <iawillia@us.ibm.com>2015-01-30 13:01:34 -0600
commit9a44d77296981912a412d741f3198c6a761ac5c0 (patch)
treefb18272bdb90746bf3f586db77a2c3225d7bd6af /src/include
parent5d05de78f647d44c570429463c49c92a06abcd90 (diff)
downloadblackbird-hostboot-9a44d77296981912a412d741f3198c6a761ac5c0.tar.gz
blackbird-hostboot-9a44d77296981912a412d741f3198c6a761ac5c0.zip
deconfigure MBA if no DIMMs are functional
update existing discoverTargets() code to also check for MBAs that do not have functional DIMM children, and deconfigure them. Change-Id: I4926195ba7b0fd829575a60cf5442ad22358a4a6 RTC: 79862 Reviewed-on: http://gfw160.aus.stglabs.ibm.com:8080/gerrit/15331 Tested-by: Jenkins Server Reviewed-by: STEPHEN M. CPREK <smcprek@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include')
-rw-r--r--src/include/usr/hwas/common/deconfigGard.H16
-rw-r--r--src/include/usr/hwas/common/hwas.H4
2 files changed, 11 insertions, 9 deletions
diff --git a/src/include/usr/hwas/common/hwas.H b/src/include/usr/hwas/common/hwas.H
index 3e51bc5c3..0a1236679 100644
--- a/src/include/usr/hwas/common/hwas.H
+++ b/src/include/usr/hwas/common/hwas.H
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2012,2014 */
+/* Contributors Listed Below - COPYRIGHT 2012,2015 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -136,10 +136,8 @@ struct TargetInfo
{
TARGETING::ATTR_AFFINITY_PATH_type affinityPath;
TARGETING::Target * pThisTarget;
- TARGETING::ATTR_HUID_type huid;
TARGETING::ATTR_TYPE_type type;
HWAS::DeconfigGard::DeconfiguredByReason reason;
- bool functional;
};
// Structure populated in invokePresentByAssoc() for use in presentByAssoc()
OpenPOWER on IntegriCloud
diff --git a/src/include/usr/hwas/common/deconfigGard.H b/src/include/usr/hwas/common/deconfigGard.H
index 65ec27bf9..b9fd4a754 100644
--- a/src/include/usr/hwas/common/deconfigGard.H
+++ b/src/include/usr/hwas/common/deconfigGard.H
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2012,2014 */
+/* Contributors Listed Below - COPYRIGHT 2012,2015 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -116,8 +116,7 @@ public:
// set by call_mss_getecid() in dmi_training.c
DECONFIGURED_BY_MEMORY_CONFIG, // BASE | 0x03
- // set by discover_targets() when mcs is disabled b/c there
- // is a non functional membuf
+ // set by presentByAssoc() when a MCS has no MEMBUFs
DECONFIGURED_BY_NO_CHILD_MEMBUF, // BASE | 0x04
// set by deconfigureAssocProc() in hwas/common/deconfigGard.C
@@ -132,16 +131,21 @@ public:
// set for SPCN initiated deconfigure
DECONFIGURED_BY_SPCN, // BASE | 0x08
- // set by discoverTargets() when functional children
- // are found connected to a non-functional Centaur
+ // set by presentByAssoc() when a MBA has no MEMBUF
DECONFIGURED_BY_NO_PARENT_MEMBUF, // BASE | 0x09
// set by presentByAssoc() when a MEMBUF has no DIMMs
DECONFIGURED_BY_NO_CHILD_DIMM, // BASE | 0x0A
// set by presentByAssoc() when a MEMBUF has no MCS
DECONFIGURED_BY_NO_PARENT_MCS, // BASE | 0x0B
+ // set by presentByAssoc() when a MEMBUF has no MBAs
+ DECONFIGURED_BY_NO_CHILD_MBA, // BASE | 0x0C
+
+ // set by presentByAssoc() when a DIMM has no MBA
+ DECONFIGURED_BY_NO_PARENT_MBA, // BASE | 0x0D
+
// mask - these bits mean it's a PLID and not an enum
DECONFIGURED_BY_PLID_MASK = 0xFFFF0000,
};
@@ -132,16 +131,21 @@ public:
DECONFIGURED_BY_NO_PARENT_MEMBUF, // BASE | 0x09
- // set by presentByAssoc() when a MEMBUF has no DIMMs
+ // set by presentByAssoc() when a MBA has no DIMMs
DECONFIGURED_BY_NO_CHILD_DIMM, // BASE | 0x0A
// set by presentByAssoc() when a MEMBUF has no MCS